@@ -19,6 +19,21 @@ elapsed_days <- function(end_date){
   as.POSIXlt(end_date)$mday - 1
 }
 
+#' @keywords internal
+matchColClasses <- function(df1, df2) {
+
+  sharedColNames <- names(df1)[names(df1) %in% names(df2)]
+  sharedColTypes <- sapply(df1[,sharedColNames, drop = FALSE], class)
+
+  for (n in sharedColNames) {
+    attributes(df2[,n]) <- attributes(df1[,n])
+    class(df2[, n]) <- sharedColTypes[n]
+  }
+
+  return(df2)
+}
+
+
 #' Get splits from partykit object
 #' @noRd
 #'
@@ -37,31 +52,37 @@ get_splits <- function(x) {
   return(splits)
 }
 
+
 #' @importFrom ggplot2 autoplot
 #' @export
 ggplot2::autoplot
 
+
 #' @importFrom magrittr %>%
 #' @export
 magrittr::`%>%`
 
+
 #' @keywords internal
 order_factors_exposure <- function(x, weight, decreasing) {
   counts <- sort(tapply(weight, x, FUN = sum), decreasing = !decreasing)
   factor(x, levels = names(counts))
 }
 
+
 #' @keywords internal
 scale_second_axis <- function(background, df, dfby, f_axis, s_axis, by){
   if ( isTRUE(background) ){
 
     if ( by == "NULL"){
-      df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) * max(df[[f_axis]], na.rm = TRUE)
+      df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) *
+        max(df[[f_axis]], na.rm = TRUE)
       df$s_axis_print <- round(df[[s_axis]], 0)
     }
 
     if ( by != "NULL"){
-      df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) * max(dfby[[f_axis]], na.rm = TRUE)
+      df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) *
+        max(dfby[[f_axis]], na.rm = TRUE)
       df$s_axis_print <- round(df[[s_axis]], 0)
     }
 
@@ -69,6 +90,7 @@ scale_second_axis <- function(background, df, dfby, f_axis, s_axis, by){
   return(df)
 }
 
+
 #' @keywords internal
 separation_mark <- function(dec.mark){
   if ( dec.mark == "," ){
@@ -78,6 +100,7 @@ separation_mark <- function(dec.mark){
   }
 }
 
+
 #' @keywords internal
 sort_x_axis <- function(sort_manual, label_width){ # hist_sort
   if ( !is.null(sort_manual) ){
@@ -91,15 +114,42 @@ sort_x_axis <- function(sort_manual, label_width){ # hist_sort
   }
 }
 
+#' @importFrom colorspace lighten
+#' @keywords internal
+lighten_color <- function(color, amount = 0.25, n = 3){
+  x <- vector(mode = "character", length = n)
+  x[1] <- color
+  if (n > 1){
+    for (i in 2:n){
+      x[i] <- colorspace::lighten(color, i * amount)
+    }
+    x
+  }
+}
+
+#' @importFrom colorspace darken
+#' @keywords internal
+darken_color <- function(color, amount = 0.25, n = 3){
+  x <- vector(mode = "character", length = n)
+  x[1] <- color
+  if (n > 1){
+    for (i in 2:n){
+      x[i] <- colorspace::darken(color, i * amount)
+    }
+    x
+  }
+}
+
 
 
 #' @keywords internal
 ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg, sep_mark, by){
+  fill_bg <- lighten_color(color_bg)[2]
   if ( isTRUE(background) & by == "NULL" ){
 
       list(
         ggplot2::geom_bar(data = df, aes(x = .data[[xvar]], y = .data[["s_axis_scale"]]),
-                          stat = "identity", color = color_bg, fill = color_bg, alpha = 0.4),
+                          stat = "identity", color = color_bg, fill = fill_bg, alpha = 1),
         ggplot2::scale_y_continuous(sec.axis = sec_axis(~ . * max(df[[s_axis]]) / max(df[[f_axis]]),
                                                         name = s_axis,
                                                         labels = sep_mark),
@@ -114,7 +164,7 @@ ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg, sep_
 
     list(
       ggplot2::geom_bar(data = df, aes(x = .data[[xvar]], y = .data[["s_axis_scale"]]),
-                        stat = "identity", color = color_bg, fill = color_bg, alpha = 0.4),
+                        stat = "identity", color = color_bg, fill = fill_bg, alpha = 1),
       ggplot2::scale_y_continuous(sec.axis = sec_axis(~ . * max(df[[s_axis]], na.rm = TRUE) / max(dfby[[f_axis]], na.rm = TRUE),
                                                       name = s_axis,
                                                       labels = sep_mark),
@@ -128,24 +178,40 @@ ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg, sep_
   else{ NULL }
 }
 
+
 #' @keywords internal
 ggpointline <- function(df, dfby, xvar, y, color, by){
   if ( by == "NULL"){
     list(
-      ggplot2::geom_point(data = df, aes(x = .data[[xvar]], y = .data[[y]]), color = color),
-      ggplot2::geom_line(data = df, aes(x = .data[[xvar]], y = .data[[y]], group = 1), color = color),
+      ggplot2::geom_point(data = df,
+                          aes(x = .data[[xvar]],
+                              y = .data[[y]]),
+                          color = color),
+      ggplot2::geom_line(data = df,
+                         aes(x = .data[[xvar]],
+                             y = .data[[y]],
+                             group = 1),
+                         color = color),
       ggplot2::theme_minimal()
     )
   } else {
     list(
-      ggplot2::geom_point(data = dfby, aes(x = .data[[xvar]], y = .data[[y]], color = .data[[by]])),
-      ggplot2::geom_line(data = dfby, aes(x = .data[[xvar]], y = .data[[y]], group = .data[[by]], color = as.factor(.data[[by]]))),
+      ggplot2::geom_point(data = dfby,
+                          aes(x = .data[[xvar]],
+                              y = .data[[y]],
+                              color = .data[[by]])),
+      ggplot2::geom_line(data = dfby,
+                         aes(x = .data[[xvar]],
+                             y = .data[[y]],
+                             group = .data[[by]],
+                             color = as.factor(.data[[by]]))),
       ggplot2::theme_minimal(),
       ggplot2::labs(color = by)
     )
   }
 }
 
+
 #' @keywords internal
 gglabels <- function(background, labels, df, xvar, sep_mark){
   if ( isTRUE(background) & isTRUE(labels) ){
@@ -159,6 +225,7 @@ gglabels <- function(background, labels, df, xvar, sep_mark){
   } else { NULL }
 }
 
+
 #' @keywords internal
 ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark){
 
@@ -166,15 +233,23 @@ ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark){
 
   if ( isTRUE(coord_flip) ){
     list(
-      ggplot2::geom_text(data = df, aes(x = .data[[xvar]], y = .data[[y]], label = sep_mark(.data[["y_print"]])),
-                         hjust = "inward", size = 3)
+      ggplot2::geom_text(data = df,
+                         aes(x = .data[[xvar]],
+                             y = .data[[y]],
+                             label = sep_mark(.data[["y_print"]])),
+                         hjust = "inward",
+                         size = 3)
     )
   }
 
   else if ( !isTRUE(coord_flip) ) {
     list(
-      ggplot2::geom_text(data = df, aes(x = .data[[xvar]], y = .data[[y]], label = sep_mark(.data[["y_print"]])),
-                         vjust = "inward", size = 3)
+      ggplot2::geom_text(data = df,
+                         aes(x = .data[[xvar]],
+                             y = .data[[y]],
+                             label = sep_mark(.data[["y_print"]])),
+                         vjust = "inward",
+                         size = 3)
     )
   }
 }
@@ -189,6 +264,7 @@ ggyscale <- function(background, sep_mark){
   }
 }
 
+
 #' @keywords internal
 ggbarline <- function(background, df, dfby, xvar, f_axis, f_axis_name, exposure, color_bg, color, sep_mark, by, labels, sort_manual, label_width){
   df <- scale_second_axis(background, df, dfby, f_axis, exposure, by)
@@ -201,11 +277,13 @@ ggbarline <- function(background, df, dfby, xvar, f_axis, f_axis_name, exposure,
     sort_x_axis(sort_manual, label_width)
 }
 
+
 #' @keywords internal
 ggbar <- function(df, xvar, f_axis, color_bg, sep_mark, coord_flip){
+  fill_bg <- lighten_color(color_bg)[2]
   ggplot2::ggplot(data = df) +
     ggplot2::geom_bar(data = df, aes(x = .data[[xvar]], y = .data[[f_axis]]),
-                      stat = "identity", color = color_bg, fill = color_bg, alpha = 0.4) +
+                      stat = "identity", color = color_bg, fill = fill_bg, alpha = 1) +
     ggplot2::theme_minimal() +
     ggplot2::labs(y = f_axis, x = xvar) +
     ggplot2::scale_y_continuous(labels = sep_mark) +
@@ -213,6 +291,7 @@ ggbar <- function(df, xvar, f_axis, color_bg, sep_mark, coord_flip){
     ggcoordflip(coord_flip)
 }
 
+
 #' @keywords internal
 ggcoordflip <- function(coord_flip){
   if ( isTRUE(coord_flip) ) {
@@ -222,6 +301,7 @@ ggcoordflip <- function(coord_flip){
   } else { NULL }
 }
 
+
 #' @keywords internal
 update_tickmarks_right <- function(plot_obj,
                                    cut_off,
@@ -242,6 +322,7 @@ update_tickmarks_right <- function(plot_obj,
               tick_labels    = c(tick_labels, label_to_add)))
 }
 
+
 #' @keywords internal
 overlap_right <- function(positions, cut_off) {
 
@@ -249,9 +330,9 @@ overlap_right <- function(positions, cut_off) {
   n <- length(positions)
   ticks_dif <- positions[n] - positions[n-1]
   (cut_off - positions[n]) / ticks_dif < 0.25
-
 }
 
+
 #' @importFrom ggplot2 ggplot_build
 #' @keywords internal
 update_tickmarks_left <- function(plot_obj,
@@ -271,6 +352,7 @@ update_tickmarks_left <- function(plot_obj,
               tick_labels    = c(label_to_add, tick_labels)))
 }
 
+
 #' @keywords internal
 overlap_left <- function(positions, cut_off) {
   positions <- positions[!is.na(positions)]
@@ -278,6 +360,7 @@ overlap_left <- function(positions, cut_off) {
   (positions[1] - cut_off) / ticks_dif < 0.25
 }
 
+
 #' @importFrom ggplot2 autoplot
 #' @import data.table
 #' @keywords internal
@@ -287,17 +370,17 @@ split_x_fn <- function(data, x, left = NULL, right = NULL){
   vec_new <- data.table::data.table(data)[get(x) > right, c(x) := right][get(x) < left, c(x) := left][,get(x)]
 
   if ( !is.null(left) ){
-    if ( left <= min(vec, na.rm = TRUE)){ stop( "Left should be greater than minimum value" ) }
-    if ( left >= max(vec, na.rm = TRUE)){ stop( "Left should be less than maximum value" )}
+    if ( left <= min(vec, na.rm = TRUE)){ stop( "Left should be greater than minimum value", call. = FALSE ) }
+    if ( left >= max(vec, na.rm = TRUE)){ stop( "Left should be less than maximum value", call. = FALSE )}
   }
 
   if ( !is.null(right) ){
-    if ( right >= max(vec, na.rm = TRUE)){ stop( "Right should be less than maximum value" ) }
-    if ( right <= min(vec, na.rm = TRUE)){ stop( "Right should be greater than minimum value")}
+    if ( right >= max(vec, na.rm = TRUE)){ stop( "Right should be less than maximum value", call. = FALSE ) }
+    if ( right <= min(vec, na.rm = TRUE)){ stop( "Right should be greater than minimum value", call. = FALSE)}
   }
 
   if ( !is.null(left) & !is.null(right)){
-    if ( left >= right ){ stop( "Right should be larger than left") }
+    if ( left >= right ){ stop( "Right should be larger than left", call. = FALSE) }
   }
 
   l1 <- split(vec_new, cut(vec_new,
